package ru.myitschool.work.ui.main

import android.content.Context
import android.content.Intent
import android.content.SharedPreferences
import android.os.Bundle
import android.util.Log
import androidx.activity.enableEdgeToEdge
import androidx.appcompat.app.AppCompatActivity
import androidx.core.content.ContextCompat
import androidx.core.view.ViewCompat
import androidx.core.view.WindowInsetsCompat
import androidx.fragment.app.Fragment
import com.example.myapplication.core.RoleConstants
import com.example.myapplication.core.SettingConstants
import com.google.android.material.bottomnavigation.BottomNavigationView
import ru.myitschool.work.R
import ru.myitschool.work.ui.createemployee.CreateUserFragment
import ru.myitschool.work.ui.login.LoginActivity
import ru.myitschool.work.ui.profile.ProfileFragment
import ru.myitschool.work.ui.qr.scan.QrScanFragment
import ru.myitschool.work.ui.userlist.CompanyInfoFragment

class MainActivity : AppCompatActivity() {
    private lateinit var settings: SharedPreferences

    private lateinit var bottomNavigationView: BottomNavigationView

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContentView(R.layout.activity_main)
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.main)) { v, insets ->
            val systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars())
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom)
            insets
        }

        settings = getSharedPreferences(SettingConstants.PREFS_FILE, Context.MODE_PRIVATE)

        if (settings.getLong(SettingConstants.PREF_ID, SettingConstants.ERROR_ID) == SettingConstants.ERROR_ID) {
            Log.d("Test", "(MainActivity) Пользователь не зарегистрирован, запускаем регистрацию.")
            startActivity(Intent(this, LoginActivity::class.java))
            finish()
            return
        }

        window.navigationBarColor = ContextCompat.getColor(this, R.color.teal_200)

        bottomNavigationView = findViewById(R.id.bottom_navigation_view)

        if (settings.getString(SettingConstants.PREF_ROLE, SettingConstants.DEF_VALUE) == RoleConstants.ROLE_USER) {
            val menuItem = bottomNavigationView.menu.getItem(1);
            menuItem.setVisible(false)
        }

        bottomNavigationView.setOnItemSelectedListener{ item ->
            // if (item.itemId == bottomNavigationView.selectedItemId) return@setOnItemSelectedListener false

            when (item.itemId) {
                R.id.scaner -> replaceFragment(QrScanFragment())
                R.id.office -> replaceFragment(CompanyInfoFragment())
                R.id.createEmployee -> replaceFragment(CreateUserFragment())
                //R.id.employees -> replaceFragment(EmployeesListFragment())
                R.id.profile -> replaceFragment(ProfileFragment())
            }
            window.statusBarColor = ContextCompat.getColor(this, R.color.grey)

            return@setOnItemSelectedListener true
        }
    }

    private fun replaceFragment(fragment: Fragment) {
        supportFragmentManager.beginTransaction().replace(R.id.container, fragment).commit()
    }
}